# Generated by roxygen2: do not edit by hand

S3method(print,wid_df)
S3method(print,wid_query)
export(download)
export(download_wid)
export(wid_ages)
export(wid_cache)
export(wid_cache_clear)
export(wid_cache_list)
export(wid_concepts)
export(wid_convert)
export(wid_countries)
export(wid_decode)
export(wid_encode)
export(wid_fetch)
export(wid_filter)
export(wid_gini)
export(wid_is_valid)
export(wid_metadata)
export(wid_percentile_ratio)
export(wid_percentiles)
export(wid_plot_compare)
export(wid_plot_lorenz)
export(wid_plot_timeseries)
export(wid_pop_types)
export(wid_query)
export(wid_search)
export(wid_series_types)
export(wid_set_key)
export(wid_tidy)
export(wid_top_share)
export(wid_validate)
importFrom(base64enc,base64encode)
importFrom(digest,digest)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(httr2,req_headers)
importFrom(httr2,req_perform)
importFrom(httr2,req_retry)
importFrom(httr2,req_timeout)
importFrom(httr2,req_url_query)
importFrom(httr2,request)
importFrom(httr2,resp_body_string)
importFrom(httr2,resp_check_status)
importFrom(jsonlite,fromJSON)
importFrom(scales,percent_format)
importFrom(stats,setNames)
importFrom(tools,R_user_dir)
importFrom(utils,head)
importFrom(utils,modifyList)
