# Generated by data-raw/sync_wid_dictionary.R -- do not edit by hand.
# Source: https://wid.world/codes-dictionary/  Synced: 2026-03-05
# series_types=17 ages=40 pop_types=6 countries=281 percentiles=184 concepts=464

#' @title Series type codes (\\S2.1.1)
#' @source \url{https://wid.world/codes-dictionary/}
#' @format data.frame(code, description)
#' @export

wid_series_types <- local({
  code <- c(
    "a",
    "b",
    "f",
    "g",
    "i",
    "n",
    "s",
    "t",
    "m",
    "p",
    "w",
    "y",
    "r",
    "x",
    "e",
    "k",
    "l"
  )
  description <- c(
    "average",
    "inverted Pareto-Lorenz coefficient",
    "female population",
    "Gini coefficient",
    "index",
    "population",
    "share",
    "threshold",
    "total",
    "proportion of women",
    "wealth-to-income ratio or labor/capital share",
    "wealth-to-GDP ratio",
    "Top 10/Bottom 50 ratio",
    "exchange rate (market or PPP)",
    "Total emissions",
    "Per capita emissions",
    "Average per capita group emissions"
  )
  stopifnot(length(code) == length(description))
  data.frame(code=code, description=description, stringsAsFactors=FALSE)
})


#' @title Age group codes (\\S2.1.3)
#' @description Zero-padded three-digit strings.
#' @source \url{https://wid.world/codes-dictionary/}
#' @format data.frame(code, description)
#' @export

wid_ages <- local({
  code <- c(
    "999",
    "014",
    "156",
    "997",
    "991",
    "992",
    "993",
    "994",
    "995",
    "996",
    "998",
    "201",
    "251",
    "301",
    "351",
    "401",
    "451",
    "501",
    "551",
    "601",
    "651",
    "701",
    "751",
    "801",
    "851",
    "901",
    "951",
    "111",
    "001",
    "051",
    "101",
    "151",
    "202",
    "302",
    "402",
    "502",
    "602",
    "702",
    "802",
    "902"
  )
  description <- c(
    "The population is comprised of individuals of all ages.",
    "The population is comprised of individuals in the 0 to 14 age group.",
    "The population is comprised of individuals in the 15 to 64 age group.",
    "The population is comprised of individuals over the age of 65.",
    "The population is comprised of individuals below the age of 20.",
    "The population is comprised of individuals over the age of 20.",
    "The population is comprised of individuals between the ages of 20 and 39.",
    "The population is comprised of individuals between the ages of 40 and 59.",
    "The population is comprised of individuals over the age of 60.",
    "The population is comprised of individuals between the ages of 20 and 64.",
    "The population is comprised of individuals over the age of 80.",
    "The population is comprised of individuals in the 20 to 24 age group.",
    "The population is comprised of individuals in the 25 to 29 age group.",
    "The population is comprised of individuals in the 30 to 34 age group.",
    "The population is comprised of individuals in the 35 to 39 age group.",
    "The population is comprised of individuals in the 40 to 44 age group.",
    "The population is comprised of individuals in the 45 to 49 age group.",
    "The population is comprised of individuals in the 50 to 54 age group.",
    "The population is comprised of individuals in the 55 to 59 age group.",
    "The population is comprised of individuals in the 60 to 64 age group.",
    "The population is comprised of individuals in the 65 to 69 age group.",
    "The population is comprised of individuals in the 70 to 74 age group.",
    "The population is comprised of individuals in the 75 to 79 age group.",
    "The population is comprised of individuals in the 80 to 84 age group.",
    "The population is comprised of individuals in the 85 to 89 age group.",
    "The population is comprised of individuals in the 90 to 94 age group.",
    "The population is comprised of individuals in the 95 to 99 age group.",
    "The population is comprised of individuals over the age of 99.",
    "The population is comprised of individuals in the 0 to 4 age group.",
    "The population is comprised of individuals in the 5 to 9 age group.",
    "The population is comprised of individuals in the 10 to 14 age group.",
    "The population is comprised of individuals in the 15 to 19 age group.",
    "The population is comprised of individuals in the 20 to 29 age group.",
    "The population is comprised of individuals in the 30 to 39 age group.",
    "The population is comprised of individuals in the 40 to 49 age group.",
    "The population is comprised of individuals in the 50 to 59 age group.",
    "The population is comprised of individuals in the 60 to 69 age group.",
    "The population is comprised of individuals in the 70 to 79 age group.",
    "The population is comprised of individuals in the 80 to 89 age group.",
    "The population is comprised of individuals in the 90 to 99 age group."
  )
  stopifnot(length(code) == length(description))
  data.frame(code=code, description=description, stringsAsFactors=FALSE)
})


#' @title Population unit codes (\\S2.1.4)
#' @source \url{https://wid.world/codes-dictionary/}
#' @format data.frame(code, description)
#' @export

wid_pop_types <- local({
  code <- c(
    "i",
    "j",
    "m",
    "f",
    "t",
    "e"
  )
  description <- c(
    "individuals",
    "equal-split adults",
    "male",
    "female",
    "tax unit",
    "employed"
  )
  stopifnot(length(code) == length(description))
  data.frame(code=code, description=description, stringsAsFactors=FALSE)
})


#' @title Country and region codes (\\S2.2)
#' @source \url{https://wid.world/codes-dictionary/}
#' @format data.frame(code, description)
#' @export

wid_countries <- local({
  code <- c(
    "AD",
    "AE",
    "AF",
    "AG",
    "AI",
    "AL",
    "AM",
    "AO",
    "AR",
    "AT",
    "AU",
    "AW",
    "AZ",
    "BA",
    "BB",
    "BD",
    "BE",
    "BF",
    "BG",
    "BH",
    "BI",
    "BJ",
    "BM",
    "BN",
    "BO",
    "BQ",
    "BR",
    "BS",
    "BT",
    "BW",
    "BY",
    "BZ",
    "CA",
    "CD",
    "CF",
    "CG",
    "CH",
    "CI",
    "CL",
    "CM",
    "CN",
    "CN-RU",
    "CN-UR",
    "CO",
    "CR",
    "CS",
    "CU",
    "CV",
    "CW",
    "CY",
    "CZ",
    "DD",
    "DE",
    "DE-BD",
    "DE-BY",
    "DE-HB",
    "DE-HE",
    "DE-HH",
    "DE-PR",
    "DE-SN",
    "DE-WU",
    "DJ",
    "DK",
    "DM",
    "DO",
    "DZ",
    "EC",
    "EE",
    "EG",
    "ER",
    "ES",
    "ET",
    "FI",
    "FJ",
    "FM",
    "FR",
    "GA",
    "GB",
    "GD",
    "GE",
    "GG",
    "GH",
    "GI",
    "GL",
    "GM",
    "GN",
    "GQ",
    "GR",
    "GT",
    "GW",
    "GY",
    "HK",
    "HN",
    "HR",
    "HT",
    "HU",
    "ID",
    "IE",
    "IL",
    "IM",
    "IN",
    "IQ",
    "IR",
    "IS",
    "IT",
    "JE",
    "JM",
    "JO",
    "JP",
    "KE",
    "KG",
    "KH",
    "KI",
    "KM",
    "KN",
    "KP",
    "KR",
    "KS",
    "KW",
    "KY",
    "KZ",
    "LA",
    "LB",
    "LC",
    "LI",
    "LK",
    "LR",
    "LS",
    "LT",
    "LU",
    "LV",
    "LY",
    "MA",
    "MC",
    "MD",
    "ME",
    "MG",
    "MH",
    "MK",
    "ML",
    "MM",
    "MN",
    "MO",
    "MR",
    "MS",
    "MT",
    "MU",
    "MV",
    "MW",
    "MX",
    "MY",
    "MZ",
    "NC",
    "NE",
    "NG",
    "NI",
    "NL",
    "NO",
    "NP",
    "NR",
    "NZ",
    "OM",
    "PA",
    "PE",
    "PF",
    "PG",
    "PH",
    "PK",
    "PL",
    "PR",
    "PS",
    "PT",
    "PW",
    "PY",
    "QA",
    "RO",
    "RS",
    "RU",
    "RW",
    "SA",
    "SB",
    "SC",
    "SD",
    "SE",
    "SG",
    "SI",
    "SK",
    "SL",
    "SM",
    "SN",
    "SO",
    "SR",
    "SS",
    "ST",
    "SU",
    "SV",
    "SX",
    "SY",
    "SZ",
    "TC",
    "TD",
    "TG",
    "TH",
    "TJ",
    "TL",
    "TM",
    "TN",
    "TO",
    "TR",
    "TT",
    "TV",
    "TW",
    "TZ",
    "UA",
    "UG",
    "US",
    "US-AK",
    "US-AL",
    "US-AR",
    "US-AZ",
    "US-CA",
    "US-CO",
    "US-CT",
    "US-DC",
    "US-DE",
    "US-FL",
    "US-GA",
    "US-HI",
    "US-IA",
    "US-ID",
    "US-IL",
    "US-IN",
    "US-KS",
    "US-KY",
    "US-LA",
    "US-MA",
    "US-MD",
    "US-ME",
    "US-MI",
    "US-MN",
    "US-MO",
    "US-MS",
    "US-MT",
    "US-NC",
    "US-ND",
    "US-NE",
    "US-NH",
    "US-NJ",
    "US-NM",
    "US-NV",
    "US-NY",
    "US-OH",
    "US-OK",
    "US-OR",
    "US-PA",
    "US-RI",
    "US-SC",
    "US-SD",
    "US-TN",
    "US-TX",
    "US-UT",
    "US-VA",
    "US-VT",
    "US-WA",
    "US-WI",
    "US-WV",
    "US-WY",
    "UY",
    "UZ",
    "VC",
    "VE",
    "VG",
    "VN",
    "VU",
    "WS",
    "YE",
    "YU",
    "ZA",
    "ZM",
    "ZW",
    "ZZ"
  )
  description <- c(
    "Andorra",
    "United Arab Emirates",
    "Afghanistan",
    "Antigua and Barbuda",
    "Anguilla",
    "Albania",
    "Armenia",
    "Angola",
    "Argentina",
    "Austria",
    "Australia",
    "Aruba",
    "Azerbaijan",
    "Bosnia and Herzegovina",
    "Barbados",
    "Bangladesh",
    "Belgium",
    "Burkina Faso",
    "Bulgaria",
    "Bahrain",
    "Burundi",
    "Benin",
    "Bermuda",
    "Brunei Darussalam",
    "Bolivia",
    "Bonaire",
    "Brazil",
    "Bahamas",
    "Bhutan",
    "Botswana",
    "Belarus",
    "Belize",
    "Canada",
    "DR Congo",
    "Central African Republic",
    "Congo",
    "Switzerland",
    "Cote d\u2019Ivoire",
    "Chile",
    "Cameroon",
    "China",
    "Rural China",
    "Urban China",
    "Colombia",
    "Costa Rica",
    "Czechoslovakia",
    "Cuba",
    "Cabo Verde",
    "Curacao",
    "Cyprus",
    "Czechia",
    "German Democratic Republic",
    "Germany",
    "Baden",
    "Bavaria",
    "Bremen",
    "Hesse",
    "Hamburg",
    "Prussia",
    "Saxony",
    "Wurttemberg",
    "Djibouti",
    "Denmark",
    "Dominica",
    "Dominican Republic",
    "Algeria",
    "Ecuador",
    "Estonia",
    "Egypt",
    "Eritrea",
    "Spain",
    "Ethiopia",
    "Finland",
    "Fiji",
    "Micronesia",
    "France",
    "Gabon",
    "United Kingdom",
    "Grenada",
    "Georgia",
    "Guernsey",
    "Ghana",
    "Gibraltar",
    "Greenland",
    "Gambia",
    "Guinea",
    "Equatorial Guinea",
    "Greece",
    "Guatemala",
    "Guinea-Bissau",
    "Guyana",
    "Hong Kong",
    "Honduras",
    "Croatia",
    "Haiti",
    "Hungary",
    "Indonesia",
    "Ireland",
    "Israel",
    "Isle of Man",
    "India",
    "Iraq",
    "Iran",
    "Iceland",
    "Italy",
    "Jersey",
    "Jamaica",
    "Jordan",
    "Japan",
    "Kenya",
    "Kyrgyzstan",
    "Cambodia",
    "Kiribati",
    "Comoros",
    "Saint Kitts and Nevis",
    "North Korea",
    "South Korea",
    "Kosovo",
    "Kuwait",
    "Cayman Islands",
    "Kazakhstan",
    "Lao PDR",
    "Lebanon",
    "Saint Lucia",
    "Liechtenstein",
    "Sri Lanka",
    "Liberia",
    "Lesotho",
    "Lithuania",
    "Luxembourg",
    "Latvia",
    "Libya",
    "Morocco",
    "Monaco",
    "Moldova",
    "Montenegro",
    "Madagascar",
    "Marshall Islands",
    "North Macedonia",
    "Mali",
    "Myanmar",
    "Mongolia",
    "Macao",
    "Mauritania",
    "Montserrat",
    "Malta",
    "Mauritius",
    "Maldives",
    "Malawi",
    "Mexico",
    "Malaysia",
    "Mozambique",
    "New Caledonia",
    "Niger",
    "Nigeria",
    "Nicaragua",
    "Netherlands",
    "Norway",
    "Nepal",
    "Nauru",
    "New Zealand",
    "Oman",
    "Panama",
    "Peru",
    "French Polynesia",
    "Papua New Guinea",
    "Philippines",
    "Pakistan",
    "Poland",
    "Puerto Rico",
    "Palestine",
    "Portugal",
    "Palau",
    "Paraguay",
    "Qatar",
    "Romania",
    "Serbia",
    "Russia",
    "Rwanda",
    "Saudi Arabia",
    "Solomon Islands",
    "Seychelles",
    "Sudan",
    "Sweden",
    "Singapore",
    "Slovenia",
    "Slovakia",
    "Sierra Leone",
    "San Marino",
    "Senegal",
    "Somalia",
    "Suriname",
    "South Sudan",
    "Sao Tome and Principe",
    "USSR",
    "El Salvador",
    "Sint Maarten (Dutch part)",
    "Syria",
    "Eswatini",
    "Turks and Caicos Islands",
    "Chad",
    "Togo",
    "Thailand",
    "Tajikistan",
    "Timor-Leste",
    "Turkmenistan",
    "Tunisia",
    "Tonga",
    "Turkiye",
    "Trinidad and Tobago",
    "Tuvalu",
    "Taiwan",
    "Tanzania",
    "Ukraine",
    "Uganda",
    "USA",
    "Alaska",
    "Alabama",
    "Arkansas",
    "Arizona",
    "California",
    "Colorado",
    "Connecticut",
    "District of Columbia",
    "Delaware",
    "Florida",
    "Georgia",
    "Hawaii",
    "Iowa",
    "Idaho",
    "Illinois",
    "Indiana",
    "Kansas",
    "Kentucky",
    "Louisiana",
    "Massachusetts",
    "Maryland",
    "Maine",
    "Michigan",
    "Minnesota",
    "Missouri",
    "Mississippi",
    "Montana",
    "North Carolina",
    "North Dakota",
    "Nebraska",
    "New Hampshire",
    "New Jersey",
    "New Mexico",
    "Nevada",
    "New York",
    "Ohio",
    "Oklahoma",
    "Oregon",
    "Pennsylvania",
    "Rhode Island",
    "South Carolina",
    "South Dakota",
    "Tennessee",
    "Texas",
    "Utah",
    "Virginia",
    "Vermont",
    "Washington",
    "Wisconsin",
    "West Virginia",
    "Wyoming",
    "Uruguay",
    "Uzbekistan",
    "Saint Vincent and the Grenadines",
    "Venezuela",
    "Virgin Islands, British",
    "Viet Nam",
    "Vanuatu",
    "Samoa",
    "Yemen",
    "Yugoslavia",
    "South Africa",
    "Zambia",
    "Zimbabwe",
    "Zanzibar"
  )
  stopifnot(length(code) == length(description))
  data.frame(code=code, description=description, stringsAsFactors=FALSE)
})


#' @title Percentile group codes (\\S2.3)
#' @description Enumerated from the pXpY grammar: key groups, deciles, centiles, and top-1\% fine groups.
#' @source \url{https://wid.world/codes-dictionary/}
#' @format data.frame(code, description)
#' @export

wid_percentiles <- local({
  code <- c(
    "p0p1",
    "p0p10",
    "p0p100",
    "p0p20",
    "p0p30",
    "p0p40",
    "p0p50",
    "p0p60",
    "p0p70",
    "p0p80",
    "p0p90",
    "p10p100",
    "p10p11",
    "p10p20",
    "p10p30",
    "p10p40",
    "p10p50",
    "p10p60",
    "p10p70",
    "p10p80",
    "p10p90",
    "p11p12",
    "p12p13",
    "p13p14",
    "p14p15",
    "p15p16",
    "p16p17",
    "p17p18",
    "p18p19",
    "p19p20",
    "p1p2",
    "p20p100",
    "p20p21",
    "p20p30",
    "p20p40",
    "p20p50",
    "p20p60",
    "p20p70",
    "p20p80",
    "p20p90",
    "p21p22",
    "p22p23",
    "p23p24",
    "p24p25",
    "p25p26",
    "p26p27",
    "p27p28",
    "p28p29",
    "p29p30",
    "p2p3",
    "p30p100",
    "p30p31",
    "p30p40",
    "p30p50",
    "p30p60",
    "p30p70",
    "p30p80",
    "p30p90",
    "p31p32",
    "p32p33",
    "p33p34",
    "p34p35",
    "p35p36",
    "p36p37",
    "p37p38",
    "p38p39",
    "p39p40",
    "p3p4",
    "p40p100",
    "p40p41",
    "p40p50",
    "p40p60",
    "p40p70",
    "p40p80",
    "p40p90",
    "p41p42",
    "p42p43",
    "p43p44",
    "p44p45",
    "p45p46",
    "p46p47",
    "p47p48",
    "p48p49",
    "p49p50",
    "p4p5",
    "p50p100",
    "p50p51",
    "p50p60",
    "p50p70",
    "p50p80",
    "p50p90",
    "p51p52",
    "p52p53",
    "p53p54",
    "p54p55",
    "p55p56",
    "p56p57",
    "p57p58",
    "p58p59",
    "p59p60",
    "p5p6",
    "p60p100",
    "p60p61",
    "p60p70",
    "p60p80",
    "p60p90",
    "p61p62",
    "p62p63",
    "p63p64",
    "p64p65",
    "p65p66",
    "p66p67",
    "p67p68",
    "p68p69",
    "p69p70",
    "p6p7",
    "p70p100",
    "p70p71",
    "p70p80",
    "p70p90",
    "p71p72",
    "p72p73",
    "p73p74",
    "p74p75",
    "p75p76",
    "p76p77",
    "p77p78",
    "p78p79",
    "p79p80",
    "p7p8",
    "p80p100",
    "p80p81",
    "p80p90",
    "p81p82",
    "p82p83",
    "p83p84",
    "p84p85",
    "p85p86",
    "p86p87",
    "p87p88",
    "p88p89",
    "p89p90",
    "p8p9",
    "p90p100",
    "p90p91",
    "p91p92",
    "p92p93",
    "p93p94",
    "p94p95",
    "p95p96",
    "p96p97",
    "p97p98",
    "p98p99",
    "p99.1p99.2",
    "p99.2p99.3",
    "p99.3p99.4",
    "p99.4p99.5",
    "p99.5p99.6",
    "p99.6p99.7",
    "p99.7p99.8",
    "p99.8p99.9",
    "p99.90p99.91",
    "p99.91p99.92",
    "p99.92p99.93",
    "p99.93p99.94",
    "p99.94p99.95",
    "p99.95p99.96",
    "p99.96p99.97",
    "p99.97p99.98",
    "p99.98p99.99",
    "p99.990p99.991",
    "p99.991p99.992",
    "p99.992p99.993",
    "p99.993p99.994",
    "p99.994p99.995",
    "p99.995p99.996",
    "p99.996p99.997",
    "p99.997p99.998",
    "p99.998p99.999",
    "p99.999p100",
    "p99.99p100",
    "p99.9p100",
    "p99p100",
    "p9p10"
  )
  description <- c(
    "Bottom 1%",
    "Bottom 10%",
    "Entire population",
    "Bottom 20%",
    "Bottom 30%",
    "Bottom 40%",
    "Bottom 50%",
    "Bottom 60%",
    "Bottom 70%",
    "Bottom 80%",
    "Bottom 90%",
    "Top 90%",
    "Percentiles 10\u201311",
    "Percentiles 10\u201320",
    "Percentiles 10\u201330",
    "Percentiles 10\u201340",
    "Percentiles 10\u201350",
    "Percentiles 10\u201360",
    "Percentiles 10\u201370",
    "Percentiles 10\u201380",
    "Percentiles 10\u201390",
    "Percentiles 11\u201312",
    "Percentiles 12\u201313",
    "Percentiles 13\u201314",
    "Percentiles 14\u201315",
    "Percentiles 15\u201316",
    "Percentiles 16\u201317",
    "Percentiles 17\u201318",
    "Percentiles 18\u201319",
    "Percentiles 19\u201320",
    "Percentiles 1\u20132",
    "Top 80%",
    "Percentiles 20\u201321",
    "Percentiles 20\u201330",
    "Percentiles 20\u201340",
    "Percentiles 20\u201350",
    "Percentiles 20\u201360",
    "Percentiles 20\u201370",
    "Percentiles 20\u201380",
    "Percentiles 20\u201390",
    "Percentiles 21\u201322",
    "Percentiles 22\u201323",
    "Percentiles 23\u201324",
    "Percentiles 24\u201325",
    "Percentiles 25\u201326",
    "Percentiles 26\u201327",
    "Percentiles 27\u201328",
    "Percentiles 28\u201329",
    "Percentiles 29\u201330",
    "Percentiles 2\u20133",
    "Top 70%",
    "Percentiles 30\u201331",
    "Percentiles 30\u201340",
    "Percentiles 30\u201350",
    "Percentiles 30\u201360",
    "Percentiles 30\u201370",
    "Percentiles 30\u201380",
    "Percentiles 30\u201390",
    "Percentiles 31\u201332",
    "Percentiles 32\u201333",
    "Percentiles 33\u201334",
    "Percentiles 34\u201335",
    "Percentiles 35\u201336",
    "Percentiles 36\u201337",
    "Percentiles 37\u201338",
    "Percentiles 38\u201339",
    "Percentiles 39\u201340",
    "Percentiles 3\u20134",
    "Top 60%",
    "Percentiles 40\u201341",
    "Percentiles 40\u201350",
    "Percentiles 40\u201360",
    "Percentiles 40\u201370",
    "Percentiles 40\u201380",
    "Percentiles 40\u201390",
    "Percentiles 41\u201342",
    "Percentiles 42\u201343",
    "Percentiles 43\u201344",
    "Percentiles 44\u201345",
    "Percentiles 45\u201346",
    "Percentiles 46\u201347",
    "Percentiles 47\u201348",
    "Percentiles 48\u201349",
    "Percentiles 49\u201350",
    "Percentiles 4\u20135",
    "Top 50%",
    "Percentiles 50\u201351",
    "Percentiles 50\u201360",
    "Percentiles 50\u201370",
    "Percentiles 50\u201380",
    "Percentiles 50\u201390",
    "Percentiles 51\u201352",
    "Percentiles 52\u201353",
    "Percentiles 53\u201354",
    "Percentiles 54\u201355",
    "Percentiles 55\u201356",
    "Percentiles 56\u201357",
    "Percentiles 57\u201358",
    "Percentiles 58\u201359",
    "Percentiles 59\u201360",
    "Percentiles 5\u20136",
    "Top 40%",
    "Percentiles 60\u201361",
    "Percentiles 60\u201370",
    "Percentiles 60\u201380",
    "Percentiles 60\u201390",
    "Percentiles 61\u201362",
    "Percentiles 62\u201363",
    "Percentiles 63\u201364",
    "Percentiles 64\u201365",
    "Percentiles 65\u201366",
    "Percentiles 66\u201367",
    "Percentiles 67\u201368",
    "Percentiles 68\u201369",
    "Percentiles 69\u201370",
    "Percentiles 6\u20137",
    "Top 30%",
    "Percentiles 70\u201371",
    "Percentiles 70\u201380",
    "Percentiles 70\u201390",
    "Percentiles 71\u201372",
    "Percentiles 72\u201373",
    "Percentiles 73\u201374",
    "Percentiles 74\u201375",
    "Percentiles 75\u201376",
    "Percentiles 76\u201377",
    "Percentiles 77\u201378",
    "Percentiles 78\u201379",
    "Percentiles 79\u201380",
    "Percentiles 7\u20138",
    "Top 20%",
    "Percentiles 80\u201381",
    "Percentiles 80\u201390",
    "Percentiles 81\u201382",
    "Percentiles 82\u201383",
    "Percentiles 83\u201384",
    "Percentiles 84\u201385",
    "Percentiles 85\u201386",
    "Percentiles 86\u201387",
    "Percentiles 87\u201388",
    "Percentiles 88\u201389",
    "Percentiles 89\u201390",
    "Percentiles 8\u20139",
    "Top 10%",
    "Percentiles 90\u201391",
    "Percentiles 91\u201392",
    "Percentiles 92\u201393",
    "Percentiles 93\u201394",
    "Percentiles 94\u201395",
    "Percentiles 95\u201396",
    "Percentiles 96\u201397",
    "Percentiles 97\u201398",
    "Percentiles 98\u201399",
    "Percentiles 99.1\u201399.2",
    "Percentiles 99.2\u201399.3",
    "Percentiles 99.3\u201399.4",
    "Percentiles 99.4\u201399.5",
    "Percentiles 99.5\u201399.6",
    "Percentiles 99.6\u201399.7",
    "Percentiles 99.7\u201399.8",
    "Percentiles 99.8\u201399.9",
    "Percentiles 99.9\u201399.91",
    "Percentiles 99.91\u201399.92",
    "Percentiles 99.92\u201399.93",
    "Percentiles 99.93\u201399.94",
    "Percentiles 99.94\u201399.95",
    "Percentiles 99.95\u201399.96",
    "Percentiles 99.96\u201399.97",
    "Percentiles 99.97\u201399.98",
    "Percentiles 99.98\u201399.99",
    "Percentiles 99.99\u201399.991",
    "Percentiles 99.991\u201399.992",
    "Percentiles 99.992\u201399.993",
    "Percentiles 99.993\u201399.994",
    "Percentiles 99.994\u201399.995",
    "Percentiles 99.995\u201399.996",
    "Percentiles 99.996\u201399.997",
    "Percentiles 99.997\u201399.998",
    "Percentiles 99.998\u201399.999",
    "Top 0.001%",
    "Top 0.01%",
    "Top 0.1%",
    "Top 1%",
    "Percentiles 9\u201310"
  )
  stopifnot(length(code) == length(description))
  data.frame(code=code, description=description, stringsAsFactors=FALSE)
})


#' @title Concept codes (\\S3-9)
#' @description Letters 2-6 of a WID variable code. Scraped from \\S3-6, 8-9 tables; \\S7 hardcoded from prose.
#' @source \url{https://wid.world/codes-dictionary/}
#' @format data.frame(code, description)
#' @export

wid_concepts <- local({
  code <- c(
    "cainc",
    "ccmhn",
    "ccmho",
    "ccshn",
    "ccsho",
    "ceuco",
    "ceugo",
    "ceuhn",
    "cfcco",
    "cfcfc",
    "cfcgo",
    "cfchn",
    "cfcho",
    "cfcnf",
    "cfcnp",
    "cfghg",
    "citgr",
    "colgo",
    "comhn",
    "comho",
    "comnp",
    "comnx",
    "compx",
    "comrx",
    "confc",
    "congo",
    "conhn",
    "conho",
    "connp",
    "cwagr",
    "cwbol",
    "cwboo",
    "cwbus",
    "cwcud",
    "cwdeb",
    "cwdeq",
    "cwdwe",
    "cweqi",
    "cwfie",
    "cwfin",
    "cwfiw",
    "cwhou",
    "cwlan",
    "cwnfa",
    "cwodk",
    "cwpen",
    "cwres",
    "defge",
    "defgo",
    "diinc",
    "ecoge",
    "ecogo",
    "edpge",
    "edsge",
    "edtge",
    "eduge",
    "edugo",
    "envge",
    "envgo",
    "expgo",
    "fainc",
    "fdinx",
    "fdipx",
    "fdirx",
    "fdixa",
    "fdixd",
    "fdixn",
    "ficap",
    "fidiv",
    "fiinc",
    "fiint",
    "fikgi",
    "filin",
    "fimik",
    "fimil",
    "fimix",
    "finpx",
    "finrx",
    "firen",
    "fiwag",
    "fkanx",
    "fkapx",
    "fkarx",
    "fkpin",
    "flcin",
    "flcip",
    "flcir",
    "flinc",
    "fosub",
    "fotax",
    "fpsub",
    "fptax",
    "fsubx",
    "ftaxx",
    "gdpro",
    "gfcar",
    "gfghg",
    "gfgho",
    "gicar",
    "gighg",
    "gigho",
    "gmxhn",
    "gmxho",
    "gpsge",
    "gpsgo",
    "gsmhn",
    "gsmho",
    "gsrco",
    "gsrfc",
    "gsrgo",
    "gsrhn",
    "gsrho",
    "gsrnf",
    "gsrnp",
    "gvaco",
    "gvago",
    "gvahn",
    "gvato",
    "gwagr",
    "gwbol",
    "gwbus",
    "gwcud",
    "gwdeb",
    "gwdec",
    "gwdwe",
    "gweal",
    "gweqi",
    "gwfie",
    "gwfin",
    "gwfiw",
    "gwhou",
    "gwlan",
    "gwnfa",
    "gwodk",
    "gwpen",
    "heage",
    "heago",
    "hfcar",
    "hfghd",
    "hfghg",
    "hfghn",
    "hfgho",
    "hicar",
    "highg",
    "higho",
    "houge",
    "hougo",
    "hwagr",
    "hwbol",
    "hwbus",
    "hwcud",
    "hwdeb",
    "hwdwe",
    "hweal",
    "hweqi",
    "hwfie",
    "hwfin",
    "hwfiw",
    "hwhou",
    "hwlan",
    "hwnfa",
    "hwodk",
    "hwpen",
    "icwtoq",
    "ifcar",
    "ifghg",
    "ifgho",
    "iicar",
    "iighg",
    "iigho",
    "indgo",
    "inpgo",
    "intgr",
    "intlcu",
    "inyixx",
    "iquali",
    "iwagr",
    "iwbol",
    "iwbus",
    "iwcud",
    "iwdeb",
    "iwdwe",
    "iweal",
    "iweqi",
    "iwfie",
    "iwfin",
    "iwfiw",
    "iwhou",
    "iwlan",
    "iwnfa",
    "iwodk",
    "iwpen",
    "ncanx",
    "ndpro",
    "necar",
    "neghg",
    "negho",
    "nfcar",
    "nfghg",
    "nfgho",
    "nicar",
    "nighg",
    "nigho",
    "nmxhn",
    "nmxho",
    "nncar",
    "nnfin",
    "nnghg",
    "nngho",
    "nninc",
    "npopem",
    "npopul",
    "nsmhn",
    "nsmho",
    "nsrco",
    "nsrfc",
    "nsrgo",
    "nsrhn",
    "nsrho",
    "nsrnf",
    "nsrnp",
    "ntaxad",
    "ntaxma",
    "ntaxre",
    "ntaxto",
    "ntcar",
    "ntcna",
    "ntghg",
    "ntgho",
    "ntgna",
    "ntona",
    "ntrgr",
    "nwagr",
    "nwboo",
    "nwbus",
    "nwdka",
    "nwdwe",
    "nweal",
    "nwgxa",
    "nwgxd",
    "nwhou",
    "nwlan",
    "nwnfa",
    "nwnxa",
    "nwodk",
    "ofcar",
    "ofghg",
    "ofgho",
    "oicar",
    "oighg",
    "oigho",
    "optxn",
    "ospgo",
    "othgo",
    "otpgp",
    "ottgr",
    "pfcar",
    "pfghg",
    "pinnx",
    "pinpx",
    "pinrx",
    "pitgr",
    "pkkin",
    "pllin",
    "polge",
    "polgo",
    "prgco",
    "prgfc",
    "prggo",
    "prghn",
    "prgho",
    "prgnf",
    "prgnp",
    "prico",
    "prifc",
    "prigo",
    "prihn",
    "priho",
    "prinf",
    "prinp",
    "prpco",
    "prpfc",
    "prpgo",
    "prphn",
    "prpho",
    "prpnf",
    "prpnp",
    "prtxn",
    "psugo",
    "ptdnx",
    "ptdpx",
    "ptdrx",
    "ptdxa",
    "ptdxd",
    "ptenx",
    "ptepx",
    "pterx",
    "ptexa",
    "ptexd",
    "ptfnx",
    "ptfpx",
    "ptfrn",
    "ptfrp",
    "ptfrr",
    "ptfrx",
    "ptfxa",
    "ptfxd",
    "ptfxn",
    "ptinc",
    "ptkin",
    "ptlin",
    "ptrrx",
    "ptrxa",
    "ptxgo",
    "pwagr",
    "pwbol",
    "pwbus",
    "pwcud",
    "pwdeb",
    "pwdwe",
    "pweal",
    "pweqi",
    "pwfie",
    "pwfin",
    "pwfiw",
    "pwhou",
    "pwlan",
    "pwnfa",
    "pwodk",
    "pwoff",
    "pwpen",
    "pwtgr",
    "recge",
    "recgo",
    "retgo",
    "revgo",
    "sacge",
    "sagco",
    "saggo",
    "saghn",
    "sagho",
    "sagnp",
    "sakge",
    "savco",
    "savgo",
    "savhn",
    "savho",
    "savig",
    "savin",
    "savnp",
    "scgnx",
    "scgpx",
    "scgrx",
    "scinx",
    "scipx",
    "scirx",
    "scogr",
    "sconx",
    "scopx",
    "scorx",
    "scrnx",
    "scrpx",
    "scrrx",
    "secco",
    "secfc",
    "secgo",
    "sechn",
    "secho",
    "secnf",
    "secnp",
    "segco",
    "segfc",
    "seggo",
    "seghn",
    "segho",
    "segnf",
    "segnp",
    "sopge",
    "sopgo",
    "spige",
    "spigo",
    "sprgo",
    "ssbco",
    "ssbfc",
    "ssbgo",
    "ssbhn",
    "ssbho",
    "ssbnf",
    "ssbnp",
    "sscco",
    "sscfc",
    "sscgo",
    "sschn",
    "sscho",
    "sscnf",
    "sscnp",
    "ssugo",
    "taxco",
    "taxfc",
    "taxgo",
    "taxhn",
    "taxho",
    "taxnf",
    "taxnp",
    "taxnx",
    "tbmpx",
    "tbnnx",
    "tbxrx",
    "tgmcx",
    "tgmmx",
    "tgmpx",
    "tgncx",
    "tgnmx",
    "tgnnx",
    "tgxcx",
    "tgxmx",
    "tgxrx",
    "tiwgo",
    "tiwhn",
    "tiwho",
    "tiwnp",
    "tpigo",
    "tprgo",
    "tsmpx",
    "tsnnx",
    "tsonx",
    "tsopx",
    "tsorx",
    "tstnx",
    "tstpx",
    "tstrx",
    "tsvnx",
    "tsvpx",
    "tsvrx",
    "tsxrx",
    "wcapsh",
    "wcsgni",
    "wcsnni",
    "wlabsh",
    "wlsgni",
    "wlsnni",
    "wwealc",
    "wwealg",
    "wwealh",
    "wweali",
    "wwealn",
    "wwealp",
    "xlceup",
    "xlceux",
    "xlcusp",
    "xlcusx",
    "xlcyup",
    "xlcyux",
    "xrereu",
    "xrerus",
    "xreryu",
    "ycscgv",
    "ycscnv",
    "ycsgdp",
    "ycsndp",
    "ylscgv",
    "ylscnv",
    "ylsgdp",
    "ylsndp"
  )
  description <- c(
    "(=) post-tax disposable income",
    "(+) CFC of mixed income of household sector",
    "(+) consumption of fixed capital attributable to mixed income",
    "(+) CFC of operating surplus of household sector",
    "(+) consumption of fixed capital attributable to operating surplus",
    "(+) compensation of employees of the corporate sector",
    "(+) compensation of employees of the government",
    "(+) compensation of employees\u00a0of household sector",
    "(+) CFC income of corporations",
    "(+) CFC of financial corporations",
    "(+) CFC of the general government",
    "(+) CFC of households and NPISH",
    "(+) CFC of households",
    "(+) CFC of non-financial corporations",
    "(+) CFC of NPISH",
    "(+) Personal carbon footprint (consumption only)",
    "(+) corporate income tax",
    "(+) collective consumption expenditure",
    "(+) compensation of employees",
    "(+) compensation of employees",
    "(+) compensation of employees",
    "(+) net foreign labor income",
    "(+) compensation of employees paid to the rest of the world",
    "(+) compensation of employees received from the rest of the world",
    "(-) consumption of fixed capital",
    "(-) final consumption expenditures",
    "(-) private expenditures of households and NPISH",
    "(-) private expenditures of households",
    "(-) private expenditures of NPISH",
    "(+) agricultural land",
    "(+) bonds and loans",
    "(=) book value of corporations",
    "(+) corporate business and other non-financial assets",
    "(+) currency and deposits",
    "(-) corporate debt (non-equity liability)",
    "(=) market value of corporations (equity liability)",
    "(+) dwellings",
    "(+) equities and fund shares",
    "(=) financial assets except for currency and deposits",
    "(+) financial assets",
    "(+) currency, deposits, bonds, and loans",
    "(+) corporate housing assets",
    "(+) land underlying dwellings",
    "(+) corporate non-financial assets",
    "(+) other domestic capital",
    "(+) pension funds and life insurance",
    "(+) residual corporate wealth",
    "(+) defense",
    "(+) defense",
    "(=) post-tax national income",
    "(+) economic affairs",
    "(+) economic affairs",
    "(+) education: Primary",
    "(+) education: Secondary",
    "(+) education: Tertiary",
    "(+) education",
    "(+) education",
    "(+) environment protection",
    "(+) environment protection",
    "(=) total public spending (excl. interest payment)",
    "(=) factor national income",
    "(+) net foreign direct investment income",
    "(+) foreign direct investment income",
    "(+) foreign direct investment income",
    "(+) Foreign direct investments assets",
    "(-) Foreign direct investments liabilities",
    "(+) Net foreign direct investment",
    "(+) fiscal capital income",
    "(+) dividends",
    "(=) fiscal income",
    "(+) interests",
    "(+) capital gains",
    "(+) fiscal labor income",
    "(+) capital component of mixed-income",
    "(+) labor component of mixed-income",
    "(=) mixed-income",
    "(-) foreign income paid to the rest of the world",
    "(+) foreign income received from the rest of the world",
    "(+) rents",
    "(+) wage and pensions",
    "(=) Capital Account",
    "(-) Capital transfers paid to the rest of the world",
    "(+) Capital transfers received from the rest of the world",
    "(+) net capital income",
    "(+) net foreign labor and capital income",
    "(+) labor and capital income paid to the rest of the world",
    "(+) labor and capital income from the rest of the world",
    "(=) labor factor income",
    "(+) other subsidies on production",
    "(+) other taxes on production",
    "(+) subsidies on products",
    "(+) taxes on products",
    "(+) subsidies on prod. received from the rest of the world",
    "(+) taxes on prod. paid to the rest of the world",
    "(+) gross domestic product",
    "(+) Government CO2 footprint",
    "(+) Government carbon footprint",
    "(+) Government footprint of other gases",
    "(+) Government imported CO2 emissions",
    "(+) Government imported emissions",
    "(+) Government imported emissions of other gases",
    "(+) gross mixed income of household sector",
    "(+) gross mixed income",
    "(+) general public services (excl. interest payment)",
    "(+) general public services",
    "(+) gross operating surplus and mixed income",
    "(+) gross operating surplus and mixed income",
    "(+) gross operating surplus of the corporate sector",
    "(+) gross operating surplus",
    "(+) gross operating surplus of the government",
    "(+) gross operating surplus of household sector",
    "(+) gross operating surplus",
    "(+) gross operating surplus",
    "(+) gross operating surplus and mixed income",
    "(+) gross value added of the corporate sector",
    "(+) gross value added of the government",
    "(+) gross value added of household sector",
    "(+) gross domestic product at factor-price",
    "(+) agricultural land",
    "(+) bonds and loans",
    "(+) government business and other non-financial assets",
    "(+) currency and deposits",
    "(-) liabilities",
    "(=) consolidated government debt",
    "(+) dwellings",
    "(=) net wealth of the general government",
    "(+) equities and fund shares",
    "(=) financial assets except for currency and deposits",
    "(+) financial assets",
    "(+) currency, deposits, bonds, and loans",
    "(+) government housing assets",
    "(+) land underlying dwellings",
    "(+) government non-financial assets",
    "(+) other domestic capital",
    "(+) pension funds and life insurance",
    "(+) health",
    "(+) health",
    "(+) Household indirect CO2 footprint",
    "(+) Household direct emissions",
    "(+) Household carbon footprint",
    "(+) Household indirect carbon footprint",
    "(+) Household indirect footprint of other gases",
    "(+) Household imported CO2 emissions",
    "(+) Household imported carbon emissions",
    "(+) Household imported emissions of other gases",
    "(+) housing and community amenities",
    "(+) housing and community amenities",
    "(+) agricultural land",
    "(+) bonds and loans",
    "(+) household business and other non-financial assets",
    "(+) currency and deposits",
    "(-) liabilities",
    "(+) dwellings",
    "(=) household net wealth",
    "(+) equities and fund shares",
    "(=) financial assets except for currency and deposits",
    "(+) financial assets",
    "(+) currency, deposits, bonds, and loans",
    "(+) household housing assets",
    "(+) land underlying dwellings",
    "(+) household non-financial assets",
    "(+) other domestic capital",
    "(+) pension funds and life insurance",
    "(*) Tobin Q (market value of corporations/book value of corporations)",
    "(+) Investment CO2 footprint",
    "(+) Investment carbon footprint",
    "(+) Investment footprint of other gases",
    "(+) Investment imported CO2 emissions",
    "(+) Investment imported carbon emissions",
    "(+) Investment imported emissions of other gases",
    "(+) individual consumption expenditures",
    "(-) interest paid by the government",
    "(+) indirect taxes",
    "Local currency unit change indicator",
    "Consumer price index / national income deflator",
    "Inequality transparency index",
    "(+) agricultural land",
    "(+) bonds and loans",
    "(+) non-profit institutions\u2019 business and other non-financial assets",
    "(+) currency and deposits",
    "(-) liabilities",
    "(+) dwellings",
    "(=) non-profit institutions\u2019 net wealth",
    "(+) equities and fund shares",
    "(=) financial assets except for currency and deposits",
    "(+) financial assets",
    "(+) currency, deposits, bonds, and loans",
    "(+) non-profit institutions\u2019 housing assets",
    "(+) land underlying dwellings",
    "(+) non-profit institutions\u2019 non-financial assets",
    "(+) other domestic capital",
    "(+) pension funds and life insurance",
    "(=) Current Account = pinnx + comnx + tbnnx + taxnx + scinx",
    "(+) net domestic product",
    "(+) National exported CO2 emissions",
    "(=) National exported carbon emissions",
    "(+) National exported emissions of other gases",
    "(+) National CO2 footprint",
    "(=) National carbon footprint",
    "(+) National footprint of other gases",
    "(+) National imported CO2 emissions",
    "(=) National imported carbon emissions",
    "(+) National imported emissions of other gases",
    "(+) net mixed income of household sector",
    "(+) net mixed income of households",
    "(+) National net imports of CO2 emissions",
    "(+) foreign income",
    "(=) National net imports of carbon emissions",
    "(+) National net imports of other gases",
    "(=) net national income",
    "employed population",
    "population",
    "(+) net operating surplus and mixed income",
    "(+) net operating surplus and mixed income",
    "(+) net operating surplus of the corporate sector",
    "(+) net operating surplus",
    "(+) Net operating surplus of the government (=0)",
    "(+) net operating surplus of the households and NPISH",
    "(+) net operating surplus",
    "(+) net operating surplus",
    "(+) net operating surplus",
    "number of tax units \u201a adults",
    "number of tax units \u201a married couples & single adults",
    "number of tax returns",
    "total tax population",
    "(+) National territorial CO2 emissions",
    "(+) Territorial emissions of the national productive sector and other emissions not attributed to households (CO2)",
    "(=) National territorial carbon emissions",
    "(+) National territorial emissions of other gases",
    "(+) Territorial emissions of the national productive sector and other emissions not attributed to households",
    "(+) Territorial emissions of the national productive sector and other emissions not attributed to households (Other gases)",
    "(+) non-tax revenue",
    "(+) agricultural land",
    "(=) book-value national wealth",
    "(+) national business and other non-financial assets",
    "(=) domestic capital",
    "(+) dwellings",
    "(=) net market-value national wealth",
    "(+) gross foreign assets",
    "(-) gross foreign liabilities",
    "(+) national housing assets",
    "(+) land underlying dwellings",
    "(+) national non-financial assets",
    "(=) Net foreign assets",
    "(+) other domestic capital",
    "(+) NGO CO2 footprint",
    "(+) NGO carbon footprint",
    "(+) NGO footprint of other gases",
    "(+) NGO imported CO2 emissions",
    "(+) NGO imported carbon emissions",
    "(+) NGO imported emissions of other gases",
    "(+) other subsidies less taxes on production",
    "(+) other subsidies on production",
    "(+) other government spending",
    "(+) other taxes on production",
    "(+) other taxes",
    "(=) Personal CO2 footprint",
    "(=) Personal carbon footprint",
    "(+) net foreign capital income",
    "(+) property income paid to the rest of the world",
    "(+) property income received from the rest of the world",
    "(+) personal income tax",
    "(+) pretax capital income",
    "(+) pretax labor income",
    "(+) public order and safety",
    "(+) public order and safety",
    "(=) gross primary income of corporations",
    "(=) gross primary income of financial corporations",
    "(=) gross primary income of the general government",
    "(=) gross primary income of households and NPISH",
    "(=) gross primary income of households",
    "(=) gross primary income of non-financial corporations",
    "(=) gross primary income of NPISH",
    "(+) net primary income of corporations",
    "(+) net primary income of financial corporations",
    "(+) net primary income of the general government",
    "(+) net primary income of households and non-profits",
    "(+) net primary income of households",
    "(+) net primary income of non-financial corporations",
    "(+) net primary income of non-profits",
    "(+) property income of corporations",
    "(+) property income (net)",
    "(+) property income of the government",
    "(+) property income of households and NPISH",
    "(+) property income (net)",
    "(+) property income (net)",
    "(+) property income (net)",
    "(+) subsidies less taxes on products",
    "(=) primary surplus of the government",
    "(+) net debt income",
    "(+) debt income",
    "(+) debt income",
    "(+) Portfolio debt assets",
    "(+) Portfolio debt liabilities",
    "(+) net equity income",
    "(+) equity income",
    "(+) equity income",
    "(+) Portfolio equity assets",
    "(+) Portfolio equity liabilities",
    "(+) net portfolio income",
    "(+) portfolio and other income",
    "(+) net reinvested earnings on foreign portfolio investment",
    "(+) reinvested earnings on foreign portfolio investment",
    "(+) reinvested earnings on foreign portfolio investment",
    "(+) portfolio and other income",
    "(+) Portfolio assets",
    "(-) Portfolio liabilities",
    "(+) Net foreign portfolio",
    "(=) pretax national income",
    "(+) pretax capital income",
    "(+) pretax labor income",
    "(+) reserves income",
    "(+) Foreign reserve exchange assets",
    "(+) taxes on products and production",
    "(+) agricultural land",
    "(+) bonds and loans",
    "(+) private business and other non-financial assets",
    "(+) currency and deposits",
    "(-) liabilities",
    "(+) dwellings",
    "(=) private net wealth",
    "(+) equities and fund shares",
    "(=) financial assets except for currency and deposits",
    "(+) financial assets",
    "(+) currency, deposits, bonds, and loans",
    "(+) private housing assets",
    "(+) land underlying dwellings",
    "(+) private non-financial assets",
    "(+) other domestic capital",
    "(+) offshore wealth",
    "(+) pension funds and life insurance",
    "(+) property and wealth taxes",
    "(+) recreation, culture and religion",
    "(+) recreation, culture and religion",
    "(=) total public revenue (excl. non-tax revenue)",
    "(=) total public revenue",
    "(+) social protection: social assistance in cash",
    "(+) gross savings/secondary income of corporations",
    "(+) gross savings of the general government",
    "(+) gross savings of households and NPISH",
    "(+) gross savings of households",
    "(+) gross savings of NPISH",
    "(+) social protection: social assistance in kind",
    "(+) net savings/secondary income of corporations",
    "(+) net savings of the general government",
    "(+) net savings of households and NPISH",
    "(+) net savings of households",
    "(=) gross savings of the total economy",
    "(=) net savings of the total economy",
    "(+) net savings of NPISH",
    "(+) Net public foreign transfers",
    "(-) Public foreign transfers paid to the rest of the world",
    "(+) Public foreign transfers received from the rest of the world",
    "(+) Net foreign transfers",
    "(-) Foreign transfers paid to the rest of the world",
    "(+) Foreign transfers received from the rest of the world",
    "(+) social contributions",
    "(+) Net other foreign transfers",
    "(-) Other foreign transfers paid to the rest of the world",
    "(+) Other foreign transfers received from the rest of the world",
    "(+) Net remittances",
    "(-) Remittances paid to the rest of the world",
    "(+) Remittances received from the rest of the world",
    "(+) net secondary income of corporations",
    "(+) net secondary income of financial corporations",
    "(+) net secondary income of the general government",
    "(+) net secondary income of households and non-profits",
    "(+) net secondary income of households",
    "(+) net secondary income of non-financial corporations",
    "(+) net secondary income of non-profits",
    "(=) gross secondary income/gross saving of corporations",
    "(+) gross savings of financial corporations",
    "(=) gross secondary income of the general government",
    "(=) gross secondary income of households and NPISH",
    "(=) gross secondary income of households",
    "(+) gross savings of non-financial corporations",
    "(=) gross secondary income of NPISH",
    "(+) social protection",
    "(+) social protection",
    "(+) social protection: social insurance",
    "(-) subsidies on production and imports",
    "(+) subsidies on products",
    "(+) social benefits from private employer social insurance",
    "(-) social benefits from private employer social insurance",
    "(+) social benefits paid by the government",
    "(=) social benefits received by households and NPISH",
    "(+) social benefits other than social transfers in kind",
    "(-) social benefits from private employer social insurance",
    "(+) social benefits other than social transfers in kind",
    "(+) social contributions to private employer social insurance",
    "(+) social contributions to private employer social insurance",
    "(+) social contributions received by the government",
    "(=) social contributions paid by households and NPISH",
    "(+) social contributions",
    "(+) social contributions to private employer social insurance",
    "(+) social contributions",
    "(=) secondary surplus of the government",
    "(+) corporate tax",
    "(-) corporate tax",
    "(=) direct taxes received by the government",
    "(-) direct taxes",
    "(-) direct taxes",
    "(-) corporate tax",
    "(-) direct taxes",
    "(+) subsidies less taxes on production and imports",
    "(-) Imports of goods and services",
    "(+) Trade balance (exports-imports)",
    "(+) Exports of goods and services",
    "(-) Imports of primary commodities",
    "(-) Imports of manufacturing goods",
    "(-) Imports of goods",
    "(+) Trade balance of primary commodities (exports-imports)",
    "(+) Trade balance of manufacturing goods (exports-imports)",
    "(+) Trade balance of goods (exports-imports)",
    "(+) Exports of primary commodities",
    "(+) Exports of manufacturing goods",
    "(+) Exports of goods",
    "(+) direct taxes on income and wealth",
    "(+) taxes on income and wealth paid by households",
    "(+) personal taxes on income and wealth",
    "(+) personal taxes on income and wealth",
    "(+) taxes on production and imports",
    "(+) taxes on products",
    "(-) Imports of services",
    "(+) Trade balance of services (exports-imports)",
    "(+) Trade balance\u00a0 of other services (exports-imports)",
    "(-) Imports of other services",
    "(+) Exports of other services",
    "(+) Trade balance of transport services (exports-imports)",
    "(-) Imports of transport services",
    "(+) Exports of transport services",
    "(+) Trade balance of travel services (exports-imports)",
    "(-) Imports of travel services",
    "(+) Exports of travel services",
    "(+) Exports of services",
    "Capital share of national income",
    "Capital share of total gross national income at factor-price",
    "Capital share of total national income at factor-price",
    "Labor share of national income",
    "Labor share of total gross national income at factor-price",
    "Labor share of total national income at factor-price",
    "Corporate wealth-to-income ratio",
    "Government wealth-to-income ratio",
    "Household wealth-to-income ratio",
    "Institutional wealth-to-income ratio",
    "Net national wealth-to-income ratio",
    "Private wealth-to-income ratio",
    "PPP exchange rate LCU/EUR",
    "Market exchange rate LCU/EUR",
    "PPP exchange rate LCU/USD",
    "Market exchange rate LCU/USD",
    "PPP exchange rate LCU/CNY",
    "Market exchange rate LCU/CNY",
    "Real exchange rate (EUR base)",
    "Real exchange rate (USD base)",
    "Real exchange rate (CNY base)",
    "Capital share in corporate gross value added at factor-price",
    "Capital share in corporate net\u00a0 value added at factor-price",
    "Capital share of total gross domesic product at factor-price",
    "Capital share of total net domestic product at factor-price",
    "Labor share in corporate gross value added at factor-price",
    "Labor share in corporate net\u00a0 value added at factor-price",
    "Labor share of total gross domestic product at factor-price",
    "Labor share of total net domestic product at factor-price"
  )
  stopifnot(length(code) == length(description))
  data.frame(code=code, description=description, stringsAsFactors=FALSE)
})

