% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/widr.R
\name{wid_set_key}
\alias{wid_set_key}
\title{Set WID API key}
\usage{
wid_set_key(key)
}
\arguments{
\item{key}{character API key}
}
\value{
Invisibly, the key string.
}
\description{
Set WID API key
}
