% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/concepts.R, R/data.R
\docType{data}
\name{wid_series_types}
\alias{wid_series_types}
\title{Series type codes (\\S2.1.1)}
\format{
data.frame(code, description)

A data frame with columns \code{code} and \code{description}.
}
\source{
\url{https://wid.world/codes-dictionary/}

\url{https://wid.world/codes-dictionary/}
}
\usage{
wid_series_types

wid_series_types
}
\description{
Series type codes (\\S2.1.1)

WID series type codes
}
\keyword{datasets}
