% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/code.R
\name{wid_validate}
\alias{wid_validate}
\title{Validate WID code components}
\usage{
wid_validate(
  series_type = NULL,
  concept = NULL,
  age = NULL,
  pop = NULL,
  years = NULL,
  areas = NULL,
  perc = NULL
)
}
\arguments{
\item{series_type}{One-letter series type code.}

\item{concept}{5-6 letter concept code.}

\item{age}{Three-digit age code.}

\item{pop}{One-letter population unit code.}

\item{years}{Integer vector of years.}

\item{areas}{ISO-2 area codes.}

\item{perc}{Percentile codes of the form \code{pXpY}.}
}
\value{
Invisibly, a named list of normalised inputs with the same names as
the parameters, with \code{age} zero-padded and \code{years} coerced to
integer.
}
\description{
Validate WID code components
}
\examples{
wid_validate(series_type = "s", concept = "ptinc", age = 992, pop = "j")
wid_validate(areas = c("US", "FR", "US-CA"))
}
