% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{print.wid_query}
\alias{print.wid_query}
\title{Print a wid_query object}
\usage{
\method{print}{wid_query}(x, ...)
}
\arguments{
\item{x}{A \code{wid_query} object.}

\item{...}{Additional arguments (currently ignored).}
}
\value{
Invisibly returns the input \code{x}.
}
\description{
Displays the contents of a \code{wid_query} object.
}
\examples{
q <- wid_query(indicators = "sptinc992j", areas = "US")
print(q)
}
