% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{wid_fetch}
\alias{wid_fetch}
\title{Execute a wid_query}
\usage{
wid_fetch(query, ...)
}
\arguments{
\item{query}{A \code{wid_query} object.}

\item{...}{Parameter overrides.}
}
\value{
A \code{wid_df} (a classed \code{data.frame}); see \code{\link{download_wid}}.
}
\description{
Fetch data from WID.world using a \code{wid_query} object.
}
\examples{
\donttest{
  if (nzchar(Sys.getenv("WID_API_KEY"))) {
    q <- wid_query(indicators = "sptinc992j", areas = "US", years = 2010:2020)
    wid_fetch(q)
  }
}
}
