% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/concepts.R, R/data.R
\docType{data}
\name{wid_concepts}
\alias{wid_concepts}
\title{Concept codes (\\S3-9)}
\format{
data.frame(code, description)

A data frame with columns \code{code} and \code{description}.
}
\source{
\url{https://wid.world/codes-dictionary/}

\url{https://wid.world/codes-dictionary/}
}
\usage{
wid_concepts

wid_concepts
}
\description{
Letters 2-6 of a WID variable code. Scraped from \\S3-6, 8-9 tables; \\S7 hardcoded from prose.
}
\keyword{datasets}
