% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/concepts.R, R/data.R
\docType{data}
\name{wid_pop_types}
\alias{wid_pop_types}
\title{Population unit codes (\\S2.1.4)}
\format{
data.frame(code, description)

A data frame with columns \code{code} and \code{description}.
}
\source{
\url{https://wid.world/codes-dictionary/}

\url{https://wid.world/codes-dictionary/}
}
\usage{
wid_pop_types

wid_pop_types
}
\description{
Population unit codes (\\S2.1.4)

WID population unit codes
}
\keyword{datasets}
