% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transforms.R
\name{wid_metadata}
\alias{wid_metadata}
\title{Fetch metadata for variables in a wid_df}
\usage{
wid_metadata(data)
}
\arguments{
\item{data}{A \code{wid_df}.}
}
\value{
A \code{data.frame} with columns \code{variable}, \code{country},
\code{source}, \code{method}, \code{quality}, and \code{imputation}.
}
\description{
Fetch metadata for variables in a wid_df
}
\examples{
\donttest{
  if (nzchar(Sys.getenv("WID_API_KEY"))) {
    d <- download_wid("sptinc992j", areas = "US", metadata = TRUE)
    wid_metadata(d)
  }
}
}
