% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/widr.R
\docType{package}
\name{widr-package}
\alias{widr-package}
\alias{widr}
\title{widr: Interface to the World Inequality Database (WID)}
\description{
Interface to the World Inequality Database (WID) API \url{https://wid.world}. Downloads distributional national accounts data with filters for country, year, percentile, age group, and population type. Includes code validation and reference tables. Independent implementation unaffiliated with the World Inequality Lab (WIL) or the Paris School of Economics.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/cherylisabella/widr}
  \item Report bugs at \url{https://github.com/cherylisabella/widr/issues}
}

}
\author{
\strong{Maintainer}: Cheryl Isabella Lim \email{cheryl.academic@gmail.com}

}
