% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/widr.R
\name{wid_cache_list}
\alias{wid_cache_list}
\title{List cached WID API responses}
\usage{
wid_cache_list()
}
\value{
Character vector of cache file names.
}
\description{
List cached WID API responses
}
\examples{
wid_cache_list()
}
