% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{print.wid_df}
\alias{print.wid_df}
\title{Print a wid_df object}
\usage{
\method{print}{wid_df}(x, ...)
}
\arguments{
\item{x}{A \code{wid_df} object.}

\item{...}{Additional arguments passed to \code{print()}.}
}
\value{
Invisibly returns the input \code{x}.
}
\description{
This method prints a summary of a \code{wid_df} object,
including the number of rows, countries, and variables.
}
\examples{
\donttest{
d <- data.frame(country = "US", variable = "sptinc992j",
                percentile = "p99p100", year = "2020",
                value = 0.19, age = "992", pop = "j",
                stringsAsFactors = FALSE)
class(d) <- c("wid_df", "data.frame")
print(d)
}
}
