% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{wid_filter}
\alias{wid_filter}
\title{Update a wid_query object}
\usage{
wid_filter(query, ...)
}
\arguments{
\item{query}{A \code{wid_query} object.}

\item{...}{Fields to update.}
}
\value{
The updated \code{wid_query} object.
}
\description{
Modify fields of a \code{wid_query} object, returning an updated query.
}
\examples{
q <- wid_query(indicators = "sptinc992j", areas = "US")
q <- wid_filter(q, years = 2010:2020)
}
