% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/widr.R
\name{wid_cache_clear}
\alias{wid_cache_clear}
\title{Clear all cached WID API responses}
\usage{
wid_cache_clear()
}
\value{
Invisibly, the number of files removed.
}
\description{
Clear all cached WID API responses
}
\examples{
wid_cache_clear()
}
