% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download.R
\name{wid_query}
\alias{wid_query}
\title{Build a reusable WID query object}
\usage{
wid_query(...)
}
\arguments{
\item{...}{Named arguments matching \code{\link{download_wid}()} parameters.}
}
\value{
A \code{wid_query} object (a named list with class \code{"wid_query"}).
}
\description{
Creates a \code{wid_query} object that stores query parameters for WID data fetching.
}
\examples{
q <- wid_query(indicators = "sptinc992j", areas = "US", years = 2010:2020)
}
